@@ -1,36 +1,18 @@
 """Main module."""
 
 import boto3
-from typing import Tuple, List, Generator, Dict, Deque, Any, Union, Literal
+from typing import Tuple, List, Generator, Dict, Deque, Any
 import os
 import docker
 import base64
 from collections import deque
-from mypy_boto3_ecr.type_defs import ImageDetailTypeDef
 import mypy_boto3_sts
 import mypy_boto3_ecr
-import sys
 
-
-class BaseException(Exception):
-    pass
-
-
-class MissingAWSEnvVar(BaseException):
-    def __init__(self) -> None:
-        self.message = 'Missing AWS environment variables to configure access'
-
-    def __str__(self) -> str:
-        return self.message
-
-
-class InvalidPayload(BaseException):
-    def __init__(self, missing_key: str, api_method: str):
-        self.message = f'Unexpected payload received, missing "{missing_key}" \
-from "{api_method}" call response'
-
-    def __str__(self) -> str:
-        return self.message
+from awsecr.exception import (
+    InvalidPayload,
+    MissingAWSEnvVar
+)
 
 
 def account_info(
@@ -91,66 +73,6 @@ def login_ecr(account_id: str,
     return tuple([resp, docker_client])
 
 
-class ECRImage():
-    def __init__(self,
-                 registry: str,
-                 repository: str,
-                 image: ImageDetailTypeDef):
-
-        findings: Dict[Union[Literal['CRITICAL'], Literal['HIGH'],
-                             Literal['INFORMATIONAL'], Literal['LOW'],
-                             Literal['MEDIUM'], Literal['UNDEFINED']], int]
-
-        try:
-            self.name: str = f"{registry}/{repository}:{image['imageTags'][0]}"
-            self.status: str = image['imageScanStatus']['status']
-            summary = image['imageScanFindingsSummary']
-            findings = summary['findingSeverityCounts']
-            self.size: int = image['imageSizeInBytes']
-        except KeyError as e:
-            print(f'Missing image scanning {e} information', sys.stderr)
-            findings = {'UNDEFINED': 0}
-
-        self.vulnerabilities: int = sum(findings.values())
-
-    def to_list(self) -> List[str]:
-        return [self.name, self.status, '{:.4n}'.format(self.size_in_mb()),
-                str(self.vulnerabilities)]
-
-    def size_in_mb(self):
-        return self.size / (1024 * 1000)
-
-    @staticmethod
-    def fields() -> List[str]:
-        return ['Image', 'Scan status', 'Size (MB)', 'Vulnerabilities']
-
-
-def list_ecr(account_id: str,
-             repository: str,
-             region: str = None) -> List[List[str]]:
-    ecr = boto3.client('ecr')
-
-    if region is None:
-        region = ecr.meta.region_name
-
-    images: Deque[List[str]]
-    images = deque()
-    images.append(ECRImage.fields())
-    registry = registry_fqdn(account_id=account_id, region=region)
-
-    try:
-        resp = ecr.describe_images(registryId=account_id,
-                                   repositoryName=repository)
-
-        for image in resp['imageDetails']:
-            images.append(ECRImage(registry, repository, image).to_list())
-    except ValueError as e:
-        raise InvalidPayload(missing_key=str(e),
-                             api_method='get_authorization_token')
-
-    return list(images)
-
-
 def image_push(account_id: str, repository: str, region: str,
                current_image: str) -> Generator:
     registry = registry_fqdn(account_id=account_id, region=region)
